==> django-robots-3.1.0.tar.gz: django-robots-3.1.0/setup.py <==
import re
from os import path
from setuptools import setup, find_packages


def read(*parts):
    return open(path.join(path.dirname(__file__), *parts)).read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


setup(
    name='django-robots',
    long_description=read('docs', 'index.rst'),
    version=find_version('robots', '__init__.py'),
    description='Robots exclusion application for Django, complementing Sitemaps.',
    author='Jannis Leidel',
    author_email='jannis@leidel.info',
    url='https://github.com/jazzband/django-robots/',
    packages=find_packages(),
    zip_safe=False,
    package_data={
        'robots': [
            'locale/*/LC_MESSAGES/*',
            'templates/robots/*.html',
        ],
    },
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development',
        'Topic :: Software Development :: Libraries :: Application Frameworks',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Framework :: Django',
        'Framework :: Django :: 1.11',
        'Framework :: Django :: 2.0',
    ]
)

==> django-robots-4.0.tar.gz: django-robots-4.0/setup.py <==
from os import path

from setuptools import find_packages, setup


def read(*parts):
    return open(path.join(path.dirname(__file__), *parts)).read()


setup(
    name='django-robots',
    use_scm_version=True,
    setup_requires=["setuptools_scm"],
    long_description=read("README.rst"),
    long_description_content_type='text/x-rst',
    description='Robots exclusion application for Django, complementing Sitemaps.',
    author='Jannis Leidel',
    author_email='jannis@leidel.info',
    python_requires='>1.1.1',
    url='https://github.com/jazzband/django-robots/',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    include_package_data=True,
    zip_safe=False,
    package_data={
        'robots': [
            'locale/*/LC_MESSAGES/*',
            'templates/robots/*.html',
        ],
    },
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development',
        'Topic :: Software Development :: Libraries :: Application Frameworks',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Framework :: Django',
        'Framework :: Django :: 1.11',
        'Framework :: Django :: 2.0',
        'Framework :: Django :: 3.0',
    ]
)
